spike generation
----------------
.. currentmodule:: sinabs.activation

SingleSpike
^^^^^^^^^^^
.. autoclass:: SingleSpike
    :members:

MultiSpike
^^^^^^^^^^^
.. autoclass:: MultiSpike
    :members:
